@@ -80,6 +80,12 @@ class DebugV2ParameterTypes(IntEnum):
     UART_MODEL_INSTANCES = 0x19
     APP_THREAD_LATENCY = 0x1A
     IV_INDEX_INFO = 0x1B
+    MESH_CACHE_INFO = 0x1C
+    EL_ELT_HISTORY = 0x1D
+    RRULE_SCHEDULE_REGISTER_SIZE = 0x1E
+    RRULE_NEXT_EVENT_TAI = 0x1F
+    RRULE_NEXT_EVENT_ENTRIES_ARRAY = 0x20
+    LAST_CALLS_OF_RRULE_ENTRIES = 0x21
 
     NOT_KNOWN_PARAMETER = 0xFF
 
