@@ -101,6 +101,14 @@ def BitList(size, *, reversed=False):
     return BitListAdapter(Bitwise(Bit[size * 8]), reversed)
 
 
+class SetAdapter(Adapter):
+    def _decode(self, obj, context, path):
+        return set(obj)
+
+    def _encode(self, obj, context, path):
+        return obj
+
+
 def EnumAdapter(subcon, enum):
     class _Enum(Enum):
         ENUM = enum
@@ -218,6 +226,7 @@ def EmbeddedBitStruct(name, *fields, reversed=False):
 
 
 class Opcode(Construct):
+    __construct_doc__ = Int32ub
     subcon = Int32ub
 
     def __init__(self, type=int):
@@ -276,7 +285,7 @@ class DefaultCountValidator(Adapter):
         self.unknown_value = unknown_value
 
     def _decode(self, obj, content, path):
-        if self.unknown_value and obj == (256 ** self.subcon.length) - 1:
+        if self.unknown_value and obj == (256**self.subcon.length) - 1:
             return float(sys.float_info.max)
         else:
             return (
@@ -287,7 +296,7 @@ class DefaultCountValidator(Adapter):
 
     def _encode(self, obj, content, path):
         if self.unknown_value and obj == float(sys.float_info.max):
-            return (256 ** self.subcon.length) - 1
+            return (256**self.subcon.length) - 1
         else:
             return round(obj / self.resolution)
 
@@ -421,7 +430,7 @@ class NamedSelect(Adapter):
     def __init__(self, **subconskw):
         subcons = list(NameAdapter(k / v.compile()) for k, v in subconskw.items())
         super().__init__(Select(*subcons))
-        self._subcon = Select(**subconskw)
+        self.__construct_doc__ = self._subcon = Select(**subconskw)
 
     def _decode(self, obj, context, path):
         return obj
