@@ -166,7 +166,7 @@ class ConfigClient(Model):
         ConfigOpcode.CONFIG_HEARBEAT_PUBLICATION_STATUS,
         ConfigOpcode.CONFIG_HEARBEAT_SUBSCRIPTION_STATUS,
         ConfigOpcode.CONFIG_KEY_REFRESH_PHASE_STATUS,
-        ConfigOpcode.CONFIG_LOW_POWER_NODE_POLLTIMEOUT_STATUS,
+        ConfigOpcode.CONFIG_LOW_POWER_NODE_POLL_TIMEOUT_STATUS,
         ConfigOpcode.CONFIG_MODEL_APP_STATUS,
         ConfigOpcode.CONFIG_MODEL_PUBLICATION_STATUS,
         ConfigOpcode.CONFIG_MODEL_SUBSCRIPTION_STATUS,
